( cd usr/lib64 ; rm -rf libfribidi.so.0 )
( cd usr/lib64 ; ln -sf libfribidi.so.0.0.0 libfribidi.so.0 )
( cd usr/lib64 ; rm -rf libfribidi.so )
( cd usr/lib64 ; ln -sf libfribidi.so.0.0.0 libfribidi.so )
